Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GitClient ¶
type GitClient interface {
FetchLocalRepositoryPath(ctx context.Context, source RepositorySource) (string, error)
}
type GitForge ¶
type GitForge interface {
FetchRootGroupContent(ctx context.Context) (map[string]RepositoryGroupSource, error)
FetchGroupContent(ctx context.Context, source RepositoryGroupSource) (RepositoryGroupContent, error)
}
type GitForgeCacher ¶
type GitForgeCacher interface {
GitForge
InvalidateCache(source RepositoryGroupSource)
}
type RepositoryGroupContent ¶
type RepositoryGroupContent struct {
// a map of the subgroups contained in this group, keyed by group name
// must not be nil
Groups map[string]RepositoryGroupSource
// a map of the repositories contained in this group, keyed by repository name
// must not be nil
Repositories map[string]RepositorySource
}
type RepositoryGroupSource ¶
Click to show internal directories.
Click to hide internal directories.